@@ -26,8 +26,8 @@
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
 #include <glib/gi18n.h>
+#include "common/nmv-exception.h"
 #include "nmv-call-stack.h"
-#include "nmv-exception.h"
 #include "nmv-ui-utils.h"
 #include "nmv-i-workbench.h"
 #include "nmv-i-perspective.h"
@@ -121,7 +121,7 @@ struct CallStack::Priv {
                 "CopyCallStackMenuItemAction",
                 Gtk::Stock::COPY,
                 _("_Copy"),
-                _("Copy the stack trace to the clipboard"),
+                _("Copy the call stack to the clipboard"),
                 sigc::mem_fun
                     (*this,
                      &Priv::on_call_stack_copy_to_clipboard_action),
@@ -174,14 +174,15 @@ struct CallStack::Priv {
     void on_debugger_stopped_signal (const UString &a_reason,
                                      bool a_has_frame,
                                      const IDebugger::Frame &a_frame,
-                                     int a_thread_id)
+                                     int a_thread_id,
+                                     const UString &a_cookie)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
 
         NEMIVER_TRY
         LOG_DD ("stopped, reason: " << a_reason) ;
 
-        if (a_has_frame || a_frame.line () || a_thread_id) {}
+        if (a_has_frame || a_frame.line () || a_thread_id || a_cookie.empty ()) {}
 
         if (a_reason == "exited-signaled"
             || a_reason == "exited-normally"
@@ -195,10 +196,13 @@ struct CallStack::Priv {
         NEMIVER_CATCH
     }
 
-    void on_frames_listed_signal (const vector<IDebugger::Frame> &a_stack)
+    void on_frames_listed_signal (const vector<IDebugger::Frame> &a_stack,
+                                  const UString &a_cookie)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
 
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
         THROW_IF_FAIL (debugger) ;
@@ -222,9 +226,12 @@ struct CallStack::Priv {
     }
 
     void on_frames_params_listed_signal
-            (const map<int, list<IDebugger::VariableSafePtr> > &a_frames_params)
+            (const map<int, list<IDebugger::VariableSafePtr> > &a_frames_params,
+             const UString &a_cookie)
     {
         LOG_D ("frames params listed", NMV_DEFAULT_DOMAIN) ;
+        if (a_cookie.empty ()) {}
+
         if (waiting_for_stack_args) {
             set_frame_list (frames, a_frames_params) ;
             waiting_for_stack_args = false ;
@@ -285,7 +292,7 @@ struct CallStack::Priv {
                     (*this, &CallStack::Priv::on_debugger_stopped_signal)) ;
         debugger->frames_listed_signal ().connect (sigc::mem_fun
                     (*this, &CallStack::Priv::on_frames_listed_signal)) ;
-        debugger->frames_params_listed_signal ().connect (sigc::mem_fun
+        debugger->frames_arguments_listed_signal ().connect (sigc::mem_fun
                     (*this, &CallStack::Priv::on_frames_params_listed_signal)) ;
         debugger->command_done_signal ().connect (sigc::mem_fun
                     (*this, &CallStack::Priv::on_command_done_signal)) ;
@@ -373,9 +380,10 @@ struct CallStack::Priv {
         Gtk::TreeView *tree_view = new Gtk::TreeView (store) ;
         THROW_IF_FAIL (tree_view) ;
         widget.reset (tree_view) ;
-        tree_view->append_column ("line", columns ().location) ;
-        tree_view->append_column ("function", columns ().function_name) ;
-        tree_view->append_column ("arguments", columns ().function_args) ;
+        tree_view->append_column (_("Frame"), columns ().frame_index) ;
+        tree_view->append_column (_("Line"), columns ().location) ;
+        tree_view->append_column (_("Function"), columns ().function_name) ;
+        tree_view->append_column (_("Arguments"), columns ().function_args) ;
         tree_view->set_headers_visible (true) ;
         tree_view->get_selection ()->set_mode (Gtk::SELECTION_SINGLE) ;
 
