@@ -28,9 +28,9 @@
 #include <gtkmm/treeview.h>
 #include <gtkmm/treestore.h>
 #include <gtkmm/treerowreference.h>
+#include "common/nmv-exception.h"
 #include "nmv-local-vars-inspector.h"
 #include "nmv-variables-utils.h"
-#include "nmv-exception.h"
 #include "nmv-ui-utils.h"
 #include "nmv-i-workbench.h"
 
@@ -352,7 +352,7 @@ public:
             (sigc::mem_fun (*this, &Priv::on_variable_value_signal)) ;
         debugger->variable_type_signal ().connect
             (sigc::mem_fun (*this, &Priv::on_variable_type_signal)) ;
-        debugger->frames_params_listed_signal ().connect
+        debugger->frames_arguments_listed_signal ().connect
             (sigc::mem_fun (*this, &Priv::on_frames_params_listed_signal)) ;
         debugger->pointed_variable_value_signal ().connect
             (sigc::mem_fun (*this, &Priv::on_pointed_variable_value_signal)) ;
@@ -372,9 +372,13 @@ public:
     }
 
     void on_local_variables_listed_signal
-                                (const list<IDebugger::VariableSafePtr> &a_vars)
+                                (const list<IDebugger::VariableSafePtr> &a_vars,
+                                 const UString &a_cookie)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
+
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
         set_local_variables (a_vars) ;
@@ -383,9 +387,12 @@ public:
     }
 
     void on_frames_params_listed_signal
-            (const map<int, list<IDebugger::VariableSafePtr> > &a_frames_params)
+            (const map<int, list<IDebugger::VariableSafePtr> > &a_frames_params,
+             const UString &a_cookie)
     {
         LOG_FUNCTION_SCOPE_NORMAL_D (NMV_DEFAULT_DOMAIN) ;
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
         map<int, list<IDebugger::VariableSafePtr> >::const_iterator it ;
@@ -401,10 +408,11 @@ public:
     void on_stopped_signal (const UString &a_reason,
                             bool a_has_frame,
                             const IDebugger::Frame &a_frame,
-                            int a_thread_id)
+                            int a_thread_id,
+                            const UString &a_cookie)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
-        if (a_frame.line () || a_thread_id) {}
+        if (a_frame.line () || a_thread_id || a_cookie.empty ()) {}
 
         NEMIVER_TRY
         LOG_DD ("stopped, reason: " << a_reason) ;
@@ -441,15 +449,22 @@ public:
     }
 
     void on_variable_value_signal (const UString &a_var_name,
-                                   const IDebugger::VariableSafePtr &a_var)
+                                   const IDebugger::VariableSafePtr &a_var,
+                                   const UString &a_cookie)
     {
         using namespace variables_utils ;
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
 
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
+        THROW_IF_FAIL (a_var) ;
         THROW_IF_FAIL (tree_store) ;
 
+        LOG_DD ("a_var_name: " << a_var_name) ;
+        LOG_DD ("a_var->name: " << a_var->name ()) ;
+
         std::map<UString, IDebugger::VariableSafePtr>::const_iterator it, nil ;
         std::map<UString, IDebugger::VariableSafePtr> *map_ptr = NULL ;
         Gtk::TreeRowReference *row_ref = NULL ;
@@ -531,10 +546,13 @@ public:
     }
 
     void on_variable_type_signal (const UString &a_var_name,
-                                  const UString &a_type)
+                                  const UString &a_type,
+                                  const UString &a_cookie)
     {
         using namespace variables_utils ;
         LOG_FUNCTION_SCOPE_NORMAL_DD ;
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
         LOG_DD ("var: '" << a_var_name << "', type: '" << a_type << "'") ;
@@ -557,80 +575,16 @@ public:
         NEMIVER_CATCH
     }
 
-    void on_tree_view_selection_changed_signal ()
-    {
-        using namespace variables_utils ;
-        LOG_FUNCTION_SCOPE_NORMAL_DD ;
-        NEMIVER_TRY
-
-        THROW_IF_FAIL (tree_view) ;
-        Glib::RefPtr<Gtk::TreeSelection> sel = tree_view->get_selection () ;
-        THROW_IF_FAIL (sel) ;
-        cur_selected_row = sel->get_selected () ;
-        if (!cur_selected_row) {return;}
-        IDebugger::VariableSafePtr variable =
-        (IDebugger::VariableSafePtr)cur_selected_row->get_value
-                                            (get_variable_columns ().variable) ;
-        if (!variable) {return;}
-        UString qname ;
-        variable->build_qname (qname) ;
-        LOG_DD ("row of variable '" << qname << "'") ;
-
-        NEMIVER_CATCH
-    }
-
-    void on_tree_view_row_expanded_signal (const Gtk::TreeModel::iterator &a_it,
-                                           const Gtk::TreeModel::Path &a_path)
-    {
-        using namespace variables_utils ;
-        LOG_FUNCTION_SCOPE_NORMAL_DD ;
-
-        NEMIVER_TRY
-
-        THROW_IF_FAIL (a_it) ;
-
-        if (a_path.get_depth ()) {}
-
-        IDebugger::VariableSafePtr var =
-            (IDebugger::VariableSafePtr)
-                a_it->get_value (get_variable_columns ().variable) ;
-        if (!var) {return;}
-        Gtk::TreeModel::iterator child_it = a_it->children ().begin ();
-        if (!child_it) {return;}
-        var = child_it->get_value (get_variable_columns ().variable) ;
-        if (var) {return;}
-
-        cur_selected_row = a_it ;
-        print_pointed_variable_value () ;
-
-        NEMIVER_CATCH
-    }
-
-    void on_tree_view_row_activated_signal (const Gtk::TreeModel::Path &a_path,
-                                            Gtk::TreeViewColumn *a_col)
-    {
-        using namespace variables_utils ;
-        NEMIVER_TRY
-        THROW_IF_FAIL (tree_store) ;
-        Gtk::TreeModel::iterator it = tree_store->get_iter (a_path) ;
-        UString type =
-            (Glib::ustring) it->get_value (get_variable_columns ().type) ;
-        if (type == "") {return;}
-
-        if (a_col != tree_view->get_column (2)) {return;}
-        cur_selected_row = it ;
-        show_variable_type_in_dialog () ;
-        NEMIVER_CATCH
-    }
-
-
     void on_pointed_variable_value_signal
                                 (const UString &a_var_name,
-                                 const IDebugger::VariableSafePtr &a_var)
+                                 const IDebugger::VariableSafePtr &a_var,
+                                 const UString &a_cookie)
     {
         using namespace variables_utils ;
         LOG_FUNCTION_SCOPE_NORMAL_DD
 
+        if (a_cookie.empty ()) {}
+
         NEMIVER_TRY
 
         LOG_DD ("a_var_name: '" << a_var_name << "'") ;
@@ -723,6 +677,72 @@ append_pointed_variable:
         NEMIVER_CATCH
     }
 
+    void on_tree_view_selection_changed_signal ()
+    {
+        using namespace variables_utils ;
+        LOG_FUNCTION_SCOPE_NORMAL_DD ;
+        NEMIVER_TRY
+
+        THROW_IF_FAIL (tree_view) ;
+        Glib::RefPtr<Gtk::TreeSelection> sel = tree_view->get_selection () ;
+        THROW_IF_FAIL (sel) ;
+        cur_selected_row = sel->get_selected () ;
+        if (!cur_selected_row) {return;}
+        IDebugger::VariableSafePtr variable =
+        (IDebugger::VariableSafePtr)cur_selected_row->get_value
+                                            (get_variable_columns ().variable) ;
+        if (!variable) {return;}
+        UString qname ;
+        variable->build_qname (qname) ;
+        LOG_DD ("row of variable '" << qname << "'") ;
+
+        NEMIVER_CATCH
+    }
+
+    void on_tree_view_row_expanded_signal (const Gtk::TreeModel::iterator &a_it,
+                                           const Gtk::TreeModel::Path &a_path)
+    {
+        using namespace variables_utils ;
+        LOG_FUNCTION_SCOPE_NORMAL_DD ;
+
+        NEMIVER_TRY
+
+        THROW_IF_FAIL (a_it) ;
+
+        if (a_path.get_depth ()) {}
+
+        IDebugger::VariableSafePtr var =
+            (IDebugger::VariableSafePtr)
+                a_it->get_value (get_variable_columns ().variable) ;
+        if (!var) {return;}
+        Gtk::TreeModel::iterator child_it = a_it->children ().begin ();
+        if (!child_it) {return;}
+        var = child_it->get_value (get_variable_columns ().variable) ;
+        if (var) {return;}
+
+        cur_selected_row = a_it ;
+        print_pointed_variable_value () ;
+
+        NEMIVER_CATCH
+    }
+
+    void on_tree_view_row_activated_signal (const Gtk::TreeModel::Path &a_path,
+                                            Gtk::TreeViewColumn *a_col)
+    {
+        using namespace variables_utils ;
+        NEMIVER_TRY
+        THROW_IF_FAIL (tree_store) ;
+        Gtk::TreeModel::iterator it = tree_store->get_iter (a_path) ;
+        UString type =
+            (Glib::ustring) it->get_value (get_variable_columns ().type) ;
+        if (type == "") {return;}
+
+        if (a_col != tree_view->get_column (2)) {return;}
+        cur_selected_row = it ;
+        show_variable_type_in_dialog () ;
+        NEMIVER_CATCH
+    }
+
 };//end class LocalVarsInspector
 
 LocalVarsInspector::LocalVarsInspector (IDebuggerSafePtr &a_debugger,
