@@ -14,7 +14,7 @@
  *See the GNU General Public License for more details.
  *
  *You should have received a copy of the
- *GNU General Public License along with Goupil;
+ *GNU General Public License along with Nemiver;
  *see the file COPYING.
  *If not, write to the Free Software Foundation,
  *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -25,21 +25,23 @@
 #include <vector>
 #include <iostream>
 #include <glib/gi18n.h>
+#include <libgnome/gnome-help.h>
+#include <libgnomevfs/gnome-vfs-init.h>
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/icontheme.h>
-#include "nmv-exception.h"
-#include "nmv-plugin.h"
+#include "common/nmv-exception.h"
+#include "common/nmv-plugin.h"
+#include "common/nmv-log-stream-utils.h"
 #include "nmv-ui-utils.h"
 #include "nmv-i-workbench.h"
 #include "nmv-i-perspective.h"
 #include "nmv-i-conf-mgr.h"
-#include <libgnomevfs/gnome-vfs-init.h>
-#include "nmv-log-stream-utils.h"
 
 using namespace std ;
 using namespace nemiver ;
 using namespace nemiver::common ;
-namespace nemiver {
+
+NEMIVER_BEGIN_NAMESPACE (nemiver)
 
 static const UString CONF_KEY_NEMIVER_WINDOW_WIDTH =
                 "/apps/nemiver/workbench/window-width" ;
@@ -91,6 +93,7 @@ private:
     //************************
     void on_quit_menu_item_action () ;
     void on_about_menu_item_action () ;
+    void on_contents_menu_item_action () ;
     void on_shutting_down_signal () ;
     //************************
     //</slots (signal callbacks)>
@@ -120,9 +123,8 @@ private:
     bool on_delete_event (GdkEventAny* event) ;
 
 public:
-    Workbench () ;
+    Workbench (DynamicModule *a_dynmod) ;
     virtual ~Workbench () ;
-    void get_info (Info &a_info) const ;
     void do_init (Gtk::Main &a_main) ;
     void shut_down () ;
     Glib::RefPtr<Gtk::ActionGroup> get_default_action_group () ;
@@ -210,6 +212,14 @@ Workbench::on_quit_menu_item_action ()
     NEMIVER_CATCH
 }
 
+void
+Workbench::on_contents_menu_item_action ()
+{
+    gnome_help_display("nemiver.xml",
+                       NULL, /*link id*/
+                       NULL /*GError*/);
+}
+
 void
 Workbench::on_about_menu_item_action ()
 {
@@ -220,15 +230,19 @@ Workbench::on_about_menu_item_action ()
     Gtk::AboutDialog dialog;
     dialog.set_name (PACKAGE_NAME);
     dialog.set_version (PACKAGE_VERSION);
-    dialog.set_comments(_("A GNOME frontend for the GNU Debugger"));
+    dialog.set_comments(_("A C/C++ debugger for GNOME"));
 
     list<Glib::ustring> authors;
-    authors.push_back("Dodji Seketeli <dodji@gnome.org>");
-    authors.push_back("Jonathon Jongsma <jjongsma@gnome.org>");
-    dialog.set_authors(authors);
+    authors.push_back ("Dodji Seketeli <dodji@gnome.org>");
+    authors.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
+    dialog.set_authors (authors);
 
-    dialog.set_website("http://home.gna.org/nemiver/");
-    dialog.set_website_label("Project Website");
+    list<Glib::ustring> documenters;
+    documenters.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
+    dialog.set_documenters (documenters);
+
+    dialog.set_website ("http://home.gna.org/nemiver/");
+    dialog.set_website_label (_("Project Website"));
 
     Glib::ustring license =
         "This program is free software; you can redistribute it and/or modify\n"
@@ -245,21 +259,23 @@ Workbench::on_about_menu_item_action ()
         "along with this program; if not, write to the \n"
         "Free Software Foundation, Inc., 59 Temple Place, Suite 330, \n"
         "Boston, MA  02111-1307  USA\n";
-    dialog.set_license(license);
+    dialog.set_license (license);
 
     // Translators: change this to your name, separate multiple names with \n
-    dialog.set_translator_credits(_("translator-credits"));
+    dialog.set_translator_credits (_("translator-credits"));
 
-    Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
-    if (theme->has_icon("nemiver")) {
-        Glib::RefPtr<Gdk::Pixbuf> icon = theme->load_icon("nemiver", 128,
-                Gtk::ICON_LOOKUP_USE_BUILTIN);
-        dialog.set_logo(icon);
+    Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default ();
+    if (theme->has_icon ("nemiver")) {
+        Glib::RefPtr<Gdk::Pixbuf> icon =
+        theme->load_icon ("nemiver", 128,
+                          Gtk::ICON_LOOKUP_USE_BUILTIN);
+        dialog.set_logo (icon);
     }
 
     vector<Glib::ustring> artists;
-    artists.push_back("Steven Brown <swjb@interchange.ubc.ca>");
-    dialog.set_artists(artists);
+    artists.push_back ("Steven Brown <swjb@interchange.ubc.ca>");
+    artists.push_back ("Andreas Nilsson <andreas@andreasn.se>");
+    dialog.set_artists (artists);
 
     dialog.run ();
 
@@ -276,7 +292,8 @@ Workbench::on_shutting_down_signal ()
     NEMIVER_CATCH
 }
 
-Workbench::Workbench ()
+Workbench::Workbench (DynamicModule *a_dynmod) :
+    IWorkbench (a_dynmod)
 {
     m_priv.reset (new Priv ());
 }
@@ -287,21 +304,12 @@ Workbench::~Workbench ()
     LOG_D ("delete", "destructor-domain") ;
 }
 
-void
-Workbench::get_info (Info &a_info) const
-{
-    static Info s_info ("workbench",
-                        "The workbench of Nemiver",
-                        "1.0") ;
-    a_info = s_info ;
-}
-
 void
 Workbench::do_init (Gtk::Main &a_main)
 {
     LOG_FUNCTION_SCOPE_NORMAL_DD ;
 
-    DynamicModule::Loader *loader = get_module_loader () ;
+    DynamicModule::Loader *loader = get_dynamic_module ().get_module_loader () ;
     THROW_IF_FAIL (loader) ;
 
     DynamicModuleManager *dynmod_manager = loader->get_dynamic_module_manager () ;
@@ -314,9 +322,18 @@ Workbench::do_init (Gtk::Main &a_main)
     // constructed)
     Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
     if (theme->has_icon("nemiver")) {
-        Glib::RefPtr<Gdk::Pixbuf> icon = theme->load_icon("nemiver", 16,
+        Glib::RefPtr<Gdk::Pixbuf> icon16 = theme->load_icon("nemiver", 16,
                 Gtk::ICON_LOOKUP_USE_BUILTIN);
-        m_priv->root_window->set_default_icon(icon);
+        Glib::RefPtr<Gdk::Pixbuf> icon32 = theme->load_icon("nemiver", 32,
+                Gtk::ICON_LOOKUP_USE_BUILTIN);
+        Glib::RefPtr<Gdk::Pixbuf> icon48 = theme->load_icon("nemiver", 48,
+                Gtk::ICON_LOOKUP_USE_BUILTIN);
+
+        std::list<Glib::RefPtr<Gdk::Pixbuf> > icon_list;
+        icon_list.push_back(icon16);
+        icon_list.push_back(icon32);
+        icon_list.push_back(icon48);
+        m_priv->root_window->set_default_icon_list(icon_list);
     }
 
     init_glade () ;
@@ -463,16 +480,19 @@ Workbench::get_configuration_manager ()
 {
     THROW_IF_FAIL (m_priv) ;
     if (!m_priv->conf_mgr) {
-        DynamicModule::Loader *loader = get_module_loader () ;
+        DynamicModule::Loader *loader =
+            get_dynamic_module ().get_module_loader () ;
         THROW_IF_FAIL (loader) ;
 
         DynamicModuleManager *dynmod_manager =
                 loader->get_dynamic_module_manager () ;
         THROW_IF_FAIL (dynmod_manager) ;
 
-        m_priv->conf_mgr = dynmod_manager->load<IConfMgr> ("gconfmgr") ;
-        m_priv->conf_mgr->do_init () ;
+        m_priv->conf_mgr = dynmod_manager->load_iface <IConfMgr> ("gconfmgr",
+                                                                  "IConfMgr") ;
         m_priv->conf_mgr->set_key_dir_to_notify ("/apps/nemiver") ;
+        m_priv->conf_mgr->add_key_to_notify (
+                "/desktop/gnome/interface/monospace_font_name") ;
     }
     THROW_IF_FAIL (m_priv->conf_mgr) ;
     return *m_priv->conf_mgr ;
@@ -624,6 +644,16 @@ Workbench::init_actions ()
             ActionEntry::DEFAULT,
             ""
         }
+        ,
+        {
+            "ContentsMenuItemAction",
+            Gtk::Stock::HELP,
+            _("_Contents"),
+            _("Display the user manual for this application"),
+            sigc::mem_fun (*this, &Workbench::on_contents_menu_item_action),
+            ActionEntry::DEFAULT,
+            "F1"
+        }
     };
 
     m_priv->default_action_group =
@@ -800,17 +830,45 @@ Workbench::select_perspective (IPerspectiveSafePtr &a_perspective)
     m_priv->bodies_container->set_current_page (body_index) ;
 }
 
+class WorkbenchModule : public DynamicModule {
+public:
+
+    void do_init ()
+    {
+        WorkbenchStaticInit::do_init ();
+    }
+
+    void get_info (Info &a_info) const
+    {
+        static Info s_info ("workbench",
+                            "The workbench of Nemiver",
+                            "1.0") ;
+        a_info = s_info ;
+    }
+
+    bool lookup_interface (const std::string &a_iface_name,
+                           DynModIfaceSafePtr &a_iface)
+    {
+        if (a_iface_name == "IWorkbench") {
+            a_iface.reset (new Workbench (this)) ;
+        } else {
+            return false ;
+        }
+        return true ;
+    }
+};//end class WorkbenchModule
+
+NEMIVER_END_NAMESPACE (nemiver)
 
 //the dynmod initial factory.
 extern "C" {
 bool
 NEMIVER_API nemiver_common_create_dynamic_module_instance (void **a_new_instance)
 {
-    *a_new_instance = new nemiver::Workbench () ;
+    *a_new_instance = new nemiver::WorkbenchModule ();
     return (*a_new_instance != 0) ;
 }
 
 }//end extern C
 
-}//end namespace nemiver
 
